import java.util.List;
import java.util.ArrayList;
import java.util.Collections;
import java.rmi.Naming;
import java.rmi.RemoteException;

interface Sorter
{
	public void sort(List<Integer> list);
}

class LocalSorter implements Sorter
{
	public LocalSorter()
	{
	}

	public void sort(List<Integer> list)
	{
		Collections.sort(list);
	}
}

class RemoteSorter implements Sorter
{
	SortServer remote;

	public RemoteSorter()
	{
		try {
			remote = (SortServer)Naming.lookup("rmi://localhost/Sort");
		}
		catch (Exception e) {
			System.err.println("RemoteSorter(): " + e.getMessage());
		}
	}

	public void sort(List<Integer> list)
	{
		try {
			remote.sort(list);
		}
		catch (Exception e) {
			System.err.println("sort(): " + e.getMessage());
		}
	}
}

public class Client 
{
	public static void testSorter(Sorter sorter)
	{
		List<Integer> numbers = new ArrayList<Integer>();

		numbers.add(1);
		numbers.add(5);
		numbers.add(2);
		numbers.add(9);
		numbers.add(7);
		numbers.add(6);

		sorter.sort(numbers);

		System.out.println(numbers);
	}

   	public static void main(String[] args) 
	{
		try {
			Sorter local = new LocalSorter();
			System.out.println("Local sorter");
			testSorter(local);

			Sorter remote = new RemoteSorter();
			System.out.println("Remote sorter");
			testSorter(remote);
		} 
		catch (Exception e) {
			System.err.println("Client: " + e.getMessage());
		}
	}
}
